#include <stdio.h>
#include <string.h>

#define WINHT		192
#define SPF		160
#define N_FR_SKIP	4

static double sf;


#if UNPADDED_CEP
static void skip_boundary ( void )
{
    int16 s[N_FR_SKIP * SPF];
    adc_file_read(s, N_FR_SKIP*SPF);
}
#endif


static char adcfile[1024];


/*
 * Build waveform from a raw adc file.  ppf = pixels/frame
 */
build_wavewin (char *file, int* ppf, int32 *nfr, int32 *winht)
{
    int16 s;
    int32 n;
    int32 mins, maxs;
    
    if ((! query_adc_input()) || (uttfile_open (file) < 0)) {
	*nfr = 0;
	*winht = 1;
	return 0;
    }

    mins = (int32) 0x7fffffff;
    maxs = (int32) 0x80000000;

#if UNPADDED_CEP
    skip_boundary ();
#endif

    for (n = 0;; n++) {
	if (adc_file_read (&s, 1) != 1)
	    break;

	if (mins > s)
	    mins = s;
	if (maxs < s)
	    maxs = s;
    }

    if (mins < 0)
	mins = -mins;
    if (maxs < 0)
	maxs = -maxs;
    if (maxs < mins)
	maxs = mins;

    sf = ((double)((WINHT>>1)-1))/((double)maxs);

    *nfr = n / SPF;
    *winht = WINHT;

    strcpy (adcfile, file);
    uttfile_close ();
    
    return 0;
}


display_wavewin (int32 ppf)
{
    int16 s;
    int32 n, p, spp;
    int32 mins, maxs;		/* pixel min/max sample */
    double scale;
    int32 miny, maxy;
    
    if ((! query_adc_input()) || (uttfile_open (adcfile) < 0))
	return 0;

#if UNPADDED_CEP
    skip_boundary ();
#endif
    
    spp = SPF/ppf;

    for (p = 0;; p++) {
	mins = (int32) 0x7fffffff;
	maxs = (int32) 0x80000000;
	for (n = 0; n < spp; n++) {
	    if (adc_file_read (&s, 1) != 1)
		break;

	    if (mins > s)
		mins = s;
	    if (maxs < s)
		maxs = s;
	}

	if (n < spp)
	    break;
	
	miny = (WINHT>>1) - mins*sf;
	maxy = (WINHT>>1) - maxs*sf;

	ui_uttwin_line ("wave", p, maxy, p, miny);
    }
    
    ui_uttwin_line ("wave", 0, (WINHT>>1), p, (WINHT>>1));
    
    uttfile_close ();
    
    return 0;
}
