/* comp.h
 *-------------------------------------------------------------*
 * HISTORY
 * Spring 94, Lin Chase (lindaq) at Carnegie Mellon
 * 	Created.
 */

#include <sys/types.h>

#define WC 128
#define MAX_SEGS 100
#define MAX_SUBS 3 
#define MAX_REGS 15
#define MAX_NAME_LEN 200

/* FORCE_OUT
 *------------------------------------------------------------*
 * DESCRIPTION
 *  Each output from the forced recognition code has the
 *    following fields.
 */ 
/* modified significantly in port away from CMU lattices files */

typedef struct _force_out_seg {
  char             word[WC];	      /* Ascii rep of the word */
  int              start_f;         /* Start frame of word */
  int              end_f;           /* End frame of word */
  long int         acoust_s;        /* Segment acoustic score */
  long int         lm_s;            /* Entering (total) lang mod score */
  char             lm_s_src[WC];     /* Entering lang mod score source */
  phone_seq_t      phone_seq;        /* phones in word */
  
}        force_out_seg_t;


typedef struct _force_out_reg {
  long int               st_seg;      /* Start segment [0..num_segs-1]*/
  long int               en_seg;      /* End segment [0..num_segs-1]*/
  long int               acoust_s;           /* Region tot acoustic score */
  long int               lm_s;               /* Region tot lang model score */
  long int               tot_s;              /* Region tot score */
  long int               pruning;            /* pruning error? = 1, 0 o/w */
  long int               align_type;         /* Keep this? */
}        force_out_reg_t;


typedef struct _force_out {
  char               utt[MAX_NAME_LEN]; /* Name of the utt in question */
  force_out_seg_t    segs[MAX_SEGS];    /* Component segments */
  int                num_segs;          /* Number of component segments */

  int                num_regs;          /* Number of component error regions */
}        force_out_t;


