/* comp.h
 *-------------------------------------------------------------*
 * HISTORY
 * Spring 94, Lin Chase (lindaq) at Carnegie Mellon
 * 	Created.
 */

#include <sys/types.h>

#define WC 128
#define MAX_SEGS 100
#define MAX_SUBS 10
#define MAX_REGS 10
#define MAX_NAME_LEN 200

/* FORCE_OUT
 *------------------------------------------------------------*
 * DESCRIPTION
 *  Each output from the forced recognition code has the
 *    following fields.
 */ 
/* modified significantly in port away from CMU lattices files */
typedef struct _force_out_seg {
  char             word[WC];	      /* Ascii rep of the word */
  int              start_f;         /* Start frame of word */
  int              end_f;           /* End frame of word */
  long int         acoust_s;        /* Segment acoustic score */
  long int         lm_s;            /* Entering (total) lang mod score */
  char             lm_s_src[WC];     /* Entering lang mod score source */
  
}        force_out_seg_t;

typedef struct _force_out_sub_reg {
  long int              st_seg;      /* Start segment [0..num_segs-1]*/
  long int              en_seg;      /* End segment [0..num_segs-1]*/
  long int              acoust_s;    /* Subregion total acoustic score */
  long int              lm_s;        /* Subregion total lang model score */
  long int              tot_s;       /* Subregion total score */
  long int              align_type;  /* 1==one word, 2==multiples, 3==LM diff only */
}        force_out_sub_reg_t;

typedef struct _force_out_reg {
  long int               st_seg;      /* Start segment [0..num_segs-1]*/
  long int               en_seg;      /* End segment [0..num_segs-1]*/
  long int               acoust_s;           /* Region tot acoustic score */
  long int               lm_s;               /* Region tot lang model score */
  long int               tot_s;              /* Region tot score */
  long int               pruning;            /* pruning error? = 1, 0 o/w */
  force_out_sub_reg_t subs[MAX_SUBS];    /* Component subregions */
  long int               num_subs;           /* Number of component subregions */
}        force_out_reg_t;

typedef struct _force_out {
  char               utt[MAX_NAME_LEN];  /* Name of the utt in question */
  force_out_seg_t    segs[MAX_SEGS];     /* Component segments */
  int                num_segs;           /* Number of component segments */
  force_out_reg_t    regs[MAX_REGS];     /* Component regions */
  int                num_regs;           /* Number of component regions */
}        force_out_t;


