#include <tcl.h>
#include <tk.h>
#include <assert.h>
#include <sys/param.h>
#include <general.h>


#define QUIT(x)		{fprintf x; exit(-1);}


/*static Tk_Window main_window;*/
/* will let my tk script create the window and let the user destroy it */
static Tcl_Interp *interp;
char *tk_script = NULL;


/* OK */
#define ui_tcl_eval(x)	_ui_tcl_eval(__FILE__, __LINE__, x)

char *_ui_tcl_eval(char *file, int32 line, char *something)
{
    Tcl_GlobalEval(interp, something);
#if 0
    if ((interp->result != NULL) && (interp->result[0] != '\0'))
	printf ("%s(%d): %s\n", file, line, interp->result);
#endif
    return interp->result;
}



void quote2blank (char *txt)
{
    int32 i;
    
    for (i = 0; txt[i]; i++)
	if (txt[i] == '"')
	    txt[i] = '~';
}

ui_ready ( void )
{
    ui_tcl_eval ("tk_ready");
}


void ui_flush_display ( void )
{
    ui_tcl_eval ("update");
}

/* not sure this is called anywhere, commenting out for now */
#if 0
ui_event_loop()
{
    int ret_val;
    char source[MAXPATHLEN];
    
    printf ("%s(%d): Reading tk script %s\n", __FILE__, __LINE__, tk_script);
    sprintf (source, "source %s", tk_script);
    ret_val = Tcl_Eval(interp, source);

    if (*interp->result != 0)
	printf("%s\n", interp->result);
    
    if (ret_val != TCL_OK)
	printf("TCL_not_OK");
}
#endif

/* am intending to call this directly */
ui_errwin_print_align (char *utt, char *refStr, char *hypStr)
{
    char str[16384];

    sprintf (str, "tk_errwin_print_align %s %s %s", utt, refStr, hypStr);
    ui_tcl_eval (str);
}

/* am intending to call this directly */

/* lmref,acref,and totref are binary indicators of whether the scores were
   bigger for the reference portion of the utterance */
/* regno is the error region number within the utterance in question */

ui_errwin_print_err (int sf, int ef, int lmref, int32 lmtot, int acref, int32 actot, int totref, int32 tot, int regno)
{
    char str[16384];

    sprintf (str, "tk_errwin_print_err %d %d %d %d %d %d %d %d %d",
	     sf,ef,lmref,lmtot,acref,actot,totref,tot,regno);
    ui_tcl_eval (str);
}

/* am intending to call this directly */
ui_errwin_print_ref_word (int sf, int ef, char *word, char *lmsrc, int32 lmscore, int32 normac)
{
    char str[16384];

    sprintf (str, "tk_errwin_print_ref_word %d %d %s %s %d %d",
	     sf,ef,word,lmsrc,lmscore,normac);
    ui_tcl_eval (str);
}

/* am intending to call this directly */
ui_errwin_print_hyp_word (int sf, int ef, char *word, char *lmsrc, int32 lmscore, int32 normac)
{
    char str[16384];

    sprintf (str, "tk_errwin_print_hyp_word %d %d %s %s %d %d",
	     sf,ef,word,lmsrc,lmscore,normac);
    ui_tcl_eval (str);
}

/* not actually intending to call this directly */
ui_errwin_line (char *win, int32 x1, int32 y1, int32 x2, int32 y2)
{
    char str[16384];

    sprintf (str, "tk_errwin_line %s %d %d %d %d", win, x1, y1, x2, y2);
    ui_tcl_eval (str);
}

/* not actually intending to call this directly */
ui_errwin_rect (char *win, int32 x1, int32 y1, int32 x2, int32 y2)
{
    char str[16384];

    sprintf (str, "tk_errwin_rect %s %d %d %d %d", win, x1, y1, x2, y2);
    ui_tcl_eval (str);
}

/* not actually intending to call this directly */
ui_errwin_text (char *win, int32 x, int32 y, char *txt, char *color)
{
    char str[16384], txtcopy[16384];
    
    /* Handle the pesky quote characters */
    strcpy (txtcopy, txt);
    quote2blank (txtcopy);

    sprintf (str, "tk_errwin_text %s %d %d \"%s\" %s", 
	     win, x, y, txtcopy, color);
    ui_tcl_eval (str);
}

/* not actually intending to call this directly */
ui_errwin_small_text (char *win, int32 x, int32 y, char *txt, char *color)
{
    char str[16384], txtcopy[16384];
    
    /* Handle the pesky quote characters */
    strcpy (txtcopy, txt);
    quote2blank (txtcopy);

    sprintf (str, "tk_errwin_small_text %s %d %d \"%s\" %s", 
	     win, x, y, txtcopy, color);
    ui_tcl_eval (str);
}

/* not actually intending to call this directly */
ui_errwin_medium_text (char *win, int32 x, int32 y, char *txt, char *color)
{
    char str[16384], txtcopy[16384];
    
    /* Handle the pesky quote characters */
    strcpy (txtcopy, txt);
    quote2blank (txtcopy);

    sprintf (str, "tk_errwin_medium_text %s %d %d \"%s\" %s", 
	     win, x, y, txtcopy, color);
    ui_tcl_eval (str);
}

/* not sure if I'll ever call this directly */
ui_errwin_create (int wd, int aht, int eht)
{
    char str[16384];
    
    sprintf (str, "tk_errwin_create %d %d %d",
	     wd, aht, eht);
    ui_tcl_eval (str);
}

/* not sure this will work, not sure the tk support will actually be there */
ui_msg (char *msg)
{
    char str[1024], msgcopy[1024];
    
    strcpy (msgcopy, msg);
    quote2blank (msgcopy);
    sprintf (str, "tk_msg \"%s\"", msgcopy);
    ui_tcl_eval (str);
}

/* set up the interpreter, turn on tcl and tk ... */
init_ui ()
{
    int ret_val;
    char source[MAXPATHLEN];
    int i;
    
    tk_script = "era.tk";

    printf("Creating tcl interpreter.\n");
    fflush(stdout);
    interp = Tcl_CreateInterp();
    
    if (Tcl_Init(interp) == TCL_ERROR) {
      printf("(1) Cannot initialize Tcl with interpreter.\n");
      fflush(stdout);
      QUIT((stdout, "%s\n", interp->result));
    }

/* Can't get this to see a value for tk_library .... */
#if 0
    if (Tk_Init(interp) == TCL_ERROR) {
      printf("(2) Cannot initialize Tk with interpreter.\n");
      fflush(stdout);
      QUIT((stdout, "%s\n", interp->result));
    }
#endif
    /* ???? what does this do???? rkm? */
    Tcl_SetResult(interp, (char*) NULL, TCL_STATIC);

/*    if (Tcl_Init(interp) == TCL_ERROR)
	QUIT((stdout, "%s\n", interp->result));*/
    
    printf ("%s(%d): Reading tk script %s\n", __FILE__, __LINE__, tk_script);
    fflush(stdout);
    sprintf (source, "source %s", tk_script);
    ret_val = Tcl_Eval(interp, source);

    if (*interp->result != 0)
	printf("%s\n", interp->result);
    
    if (ret_val != TCL_OK)
	printf("TCL_not_OK");
}




